# kervi-ui
The user interface module for Kervi. Kervi is a Python/web framework that makes it very easy to create robotic and automation projects in Python with a web based UI.
It is written primarly for Raspberry PI, but it runs on all platforms that supports Python. 

This kervi module is included via dependency when you install kervi via pip:

```
pip install kervi
```

If you want to host the ui part in another web server you can grab the kervi-ui/dist/webapp folder an install it on your web server.

for more information take a look on http://github.com/kervi/kervi